#!/usr/bin/env python3
from config import Config
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration
from flask import Flask

from model import db
from utils import register_all_error_handlers, k8s

# import views
from views import JobView

# Setup sentry

if Config.SENTRY_DSN:
    sentry_sdk.init(
        dsn=Config.SENTRY_DSN,
        integrations=[FlaskIntegration()],
        send_default_pii=True,
        release=Config.RELEASE_ID,
        environment=Config.RELEASEMODE
    )

# create flask app
app = Flask(__name__)
app.config.from_object(Config)
db.init_app(app)

# init stuffs
k8s.init_app(app)
register_all_error_handlers(app)


@app.before_first_request
def init_db():
    db.create_all()


# register views
for view in [JobView]:
    view.register(app, trailing_slash=False)

# start debuggig if needed
if __name__ == "__main__":
    app.run(debug=True)
